==> nylo_framework-0.6.1%2B1.tar.gz: README.md <==
![Nylo Banner](https://nylo.dev/images/nylo_logo_header.png)

<p align="center">
  <a href="https://github.com/nylo-core/framework/releases/tag/v0.3.1"><img src="https://img.shields.io/github/v/release/nylo-core/framework?style=plastic" alt="Latest Release Version"></a>
  <a href="https://github.com/nylo-core/framework/releases/tag/v0.3.1"><img src="https://img.shields.io/github/license/nylo-core/framework?style=plastic" alt="Latest Stable Version"></a>
  <a href="https://github.com/nylo-core/framework"><img alt="GitHub stars" src="https://img.shields.io/github/stars/nylo-core/framework?style=plastic"></a>
</p>

## Nylo Framework (Beta v0.6.1)

Nylo is a micro-framework for Flutter which is designed to help simplify app development. Every project provides a simple bolierplate and MVC pattern to help you build apps easier. 

This project is open source and MIT-licenced, we welcome any contributions. You can join as a backer/sponsor to fund future development for this project [here](https://nylo.dev/contributions)

> **Note:** If you want to build an application using Nylo, please visit the main [Nylo repository](https://github.com/nylo-core/nylo). This repository contains the code for the framework Nylo uses.

---

## Features
Some core features available 
* Auto generate models from API urls in the new apispec.json file
* Cli for generating new files 
* Router file to manage routes
* Light and dark themes preset for customization
* Localization ready
* Project structure for widgets, assets, controllers + more

## Documentation

Visit the docs on [Nylo](https://nylo.dev/docs) to view our extensive and thorough documentation. 

## Changelog
Please see [CHANGELOG](https://github.com/nylo-core/framework/blob/master/CHANGELOG.md) for more information what has changed recently.

## Social
* [Twitter](https://twitter.com/nylo_dev)

## Security
If you discover any security related issues, please email support@nylo.dev instead of using the issue tracker.

## Credits
* [Anthony Gordon](https://github.com/agordn52)

## Licence

The MIT License (MIT). Please view the [License](https://github.com/nylo-core/nylo/blob/master/licence) File for more information.

==> nylo_framework-0.7.0%2B1.tar.gz: README.md <==
![Nylo Banner](https://nylo.dev/images/nylo_logo_header.png)

<p align="center">
  <a href="https://github.com/nylo-core/framework/releases/tag/v0.3.1"><img src="https://img.shields.io/github/v/release/nylo-core/framework?style=plastic" alt="Latest Release Version"></a>
  <a href="https://github.com/nylo-core/framework/releases/tag/v0.3.1"><img src="https://img.shields.io/github/license/nylo-core/framework?style=plastic" alt="Latest Stable Version"></a>
  <a href="https://github.com/nylo-core/framework"><img alt="GitHub stars" src="https://img.shields.io/github/stars/nylo-core/framework?style=plastic"></a>
</p>

## Nylo Framework (Beta v0.7.0+1)

Nylo is a micro-framework for Flutter which is designed to help simplify app development. Every project provides a simple bolierplate and MVC pattern to help you build apps easier. 

This project is open source and MIT-licenced, we welcome any contributions. You can join as a backer/sponsor to fund future development for this project [here](https://nylo.dev/contributions)

> **Note:** If you want to build an application using Nylo, please visit the main [Nylo repository](https://github.com/nylo-core/nylo). This repository contains the code for the framework Nylo uses.

---

## Features
Some core features available 
* Auto generate models from API urls in the new apispec.json file
* Cli for generating new files 
* Router file to manage routes
* Light and dark themes preset for customization
* Localization ready
* Project structure for widgets, assets, controllers + more

## Documentation

Visit the docs on [Nylo](https://nylo.dev/docs) to view our extensive and thorough documentation. 

## Changelog
Please see [CHANGELOG](https://github.com/nylo-core/framework/blob/master/CHANGELOG.md) for more information what has changed recently.

## Social
* [Twitter](https://twitter.com/nylo_dev)

## Security
If you discover any security related issues, please email support@nylo.dev instead of using the issue tracker.

## Credits
* [Anthony Gordon](https://github.com/agordn52)

## Licence

The MIT License (MIT). Please view the [License](https://github.com/nylo-core/nylo/blob/master/licence) File for more information.
